;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "jwt" "20251022.2118"
  "Interact with JSON Web Tokens."
  '((emacs "29.1"))
  :url "https://github.com/joshbax189/jwt-el"
  :commit "d6754f8fab6ff4041a7bece1963495e99ad9fe68"
  :revdesc "d6754f8fab6f"
  :keywords '("tools" "convenience"))
